EvoDAG
=========================================

.. image:: https://travis-ci.org/mgraffg/EvoDAG.svg?branch=master
	   :target: https://travis-ci.org/mgraffg/EvoDAG

.. image:: https://ci.appveyor.com/api/projects/status/vx09qqgluff3ko5e?svg=true		    
	   :target: https://ci.appveyor.com/project/mgraffg/evodag

.. image:: https://coveralls.io/repos/github/mgraffg/EvoDAG/badge.svg?branch=master		    
	   :target: https://coveralls.io/github/mgraffg/EvoDAG?branch=master

.. image:: https://anaconda.org/ingeotec/evodag/badges/version.svg
	   :target: https://anaconda.org/ingeotec/evodag		    

.. image:: https://badge.fury.io/py/EvoDAG.svg		    
	   :target: https://badge.fury.io/py/EvoDAG


Evolving Directed Acyclic Graph (EvoDAG) is a steady-state Genetic
Programming system with tournament selection.

More information can be found on `EvoDAG <http://github.com/mgraffg/EvoDAG>`_.
